@@ -15,11 +15,7 @@ REQUIRED_AUTOMAKE_VERSION=1.7
 }
 
 which mate-autogen || {
-    echo "You need to install mate-common from the MATE Git"
+    echo "You need to install mate-common"
     exit 1
 }
-
-USE_MATE2_MACROS=1
-USE_COMMON_DOC_BUILD=yes
-
-. mate-autogen
+USE_MATE2_MACROS=1 USE_COMMON_DOC_BUILD=yes . mate-autogen
